@@ -1,6 +1,11 @@
 """Manages dvc remotes that user can use with push/pull/status commands."""
 
 import logging
+from typing import TYPE_CHECKING, Iterable, Optional
+
+if TYPE_CHECKING:
+    from dvc.objects.file import HashFile
+    from dvc.remote.base import Remote
 
 logger = logging.getLogger(__name__)
 
@@ -19,7 +24,11 @@ class DataCloud:
     def __init__(self, repo):
         self.repo = repo
 
-    def get_remote(self, name=None, command="<command>"):
+    def get_remote(
+        self,
+        name: Optional[str] = None,
+        command: str = "<command>",
+    ) -> "Remote":
         from dvc.config import NoRemoteError
 
         if not name:
@@ -48,76 +57,88 @@ class DataCloud:
 
         return get_remote(self.repo, name=name)
 
-    def push(self, cache, jobs=None, remote=None, show_checksums=False):
+    def push(
+        self,
+        objs: Iterable["HashFile"],
+        jobs: Optional[int] = None,
+        remote: Optional[str] = None,
+        show_checksums: bool = False,
+    ):
         """Push data items in a cloud-agnostic way.
 
         Args:
-            cache (NamedCache): named checksums to push to the cloud.
-            jobs (int): number of jobs that can be running simultaneously.
-            remote (dvc.remote.base.BaseRemote): optional remote to push to.
+            objs: objects to push to the cloud.
+            jobs: number of jobs that can be running simultaneously.
+            remote: optional remote to push to.
                 By default remote from core.remote config option is used.
-            show_checksums (bool): show checksums instead of file names in
+            show_checksums: show checksums instead of file names in
                 information messages.
         """
-        remote = self.get_remote(remote, "push")
+        remote_obj = self.get_remote(remote, "push")
 
-        return remote.push(
+        return remote_obj.push(
             self.repo.odb.local,
-            cache,
+            objs,
             jobs=jobs,
             show_checksums=show_checksums,
         )
 
-    def pull(self, cache, jobs=None, remote=None, show_checksums=False):
+    def pull(
+        self,
+        objs: Iterable["HashFile"],
+        jobs: Optional[int] = None,
+        remote: Optional[str] = None,
+        show_checksums: bool = False,
+    ):
         """Pull data items in a cloud-agnostic way.
 
         Args:
-            cache (NamedCache): named checksums to pull from the cloud.
-            jobs (int): number of jobs that can be running simultaneously.
-            remote (dvc.remote.base.BaseRemote): optional remote to pull from.
+            objs: objects to pull from the cloud.
+            jobs: number of jobs that can be running simultaneously.
+            remote: optional remote to pull from.
                 By default remote from core.remote config option is used.
-            show_checksums (bool): show checksums instead of file names in
+            show_checksums: show checksums instead of file names in
                 information messages.
         """
-        remote = self.get_remote(remote, "pull")
+        remote_obj = self.get_remote(remote, "pull")
 
-        return remote.pull(
+        return remote_obj.pull(
             self.repo.odb.local,
-            cache,
+            objs,
             jobs=jobs,
             show_checksums=show_checksums,
         )
 
     def status(
         self,
-        cache,
-        jobs=None,
-        remote=None,
-        show_checksums=False,
-        log_missing=True,
+        objs: Iterable["HashFile"],
+        jobs: Optional[int] = None,
+        remote: Optional[str] = None,
+        show_checksums: bool = False,
+        log_missing: bool = True,
     ):
         """Check status of data items in a cloud-agnostic way.
 
         Args:
-            cache (NamedCache): named checksums to check status for.
-            jobs (int): number of jobs that can be running simultaneously.
-            remote (dvc.remote.base.BaseRemote): optional remote to compare
+            objs: objects to check status for.
+            jobs: number of jobs that can be running simultaneously.
+            remote: optional remote to compare
                 cache to. By default remote from core.remote config option
                 is used.
-            show_checksums (bool): show checksums instead of file names in
+            show_checksums: show checksums instead of file names in
                 information messages.
-            log_missing (bool): log warning messages if file doesn't exist
+            log_missing: log warning messages if file doesn't exist
                 neither in cache, neither in cloud.
         """
-        remote = self.get_remote(remote, "status")
-        return remote.status(
+        remote_obj = self.get_remote(remote, "status")
+        return remote_obj.status(
             self.repo.odb.local,
-            cache,
+            objs,
             jobs=jobs,
             show_checksums=show_checksums,
             log_missing=log_missing,
         )
 
     def get_url_for(self, remote, checksum):
-        remote = self.get_remote(remote)
-        return str(remote.odb.hash_to_path_info(checksum))
+        remote_obj = self.get_remote(remote)
+        return str(remote_obj.odb.hash_to_path_info(checksum))
