@@ -1,6 +1,7 @@
 import json
 import logging
 import posixpath
+from typing import TYPE_CHECKING, Optional, Tuple
 
 from funcy import cached_property
 
@@ -8,6 +9,9 @@ from .errors import ObjectFormatError
 from .file import HashFile
 from .stage import get_file_hash
 
+if TYPE_CHECKING:
+    from .db.base import ObjectDB
+
 logger = logging.getLogger(__name__)
 
 
@@ -115,24 +119,45 @@ class Tree(HashFile):
         tree = cls.from_list(raw)
         tree.path_info = obj.path_info
         tree.fs = obj.fs
+        for _, entry_obj in tree:
+            entry_obj.fs = obj.fs
         tree.hash_info = hash_info
 
         return tree
 
-    def filter(self, odb, prefix):
+    def filter(
+        self, odb: "ObjectDB", prefix: Tuple[str], copy: bool = False
+    ) -> Optional[HashFile]:
+        """Return filter object(s) for this tree.
+
+        If copy is True, returned object will be a Tree containing
+        filtered entries, but with hash_info copied from the original tree.
+
+        If copy is False, returned object will be a raw HashFile or Tree with
+        newly computed hash_info for the filtered object.
+        """
         obj = self._dict.get(prefix)
         if obj:
+            if copy:
+                tree = Tree(self.path_info, self.fs, self.hash_info)
+                tree.add(prefix, obj)
+                return tree
             return obj
 
-        depth = len(prefix)
-        tree = Tree(None, None, None)
+        if copy:
+            tree = Tree(self.path_info, self.fs, self.hash_info)
+            depth = 0
+        else:
+            tree = Tree(None, None, None)
+            depth = len(prefix)
         try:
             for key, obj in self.trie.items(prefix):
                 tree.add(key[depth:], obj)
         except KeyError:
             return None
-        tree.digest()
-        odb.add(tree.path_info, tree.fs, tree.hash_info)
+        if not copy:
+            tree.digest()
+            odb.add(tree.path_info, tree.fs, tree.hash_info)
         return tree
 
 
